******************************
birdhousebuilder.recipe.docker
******************************

.. contents::

Introduction
************

``birdhousebuilder.recipe.docker`` is a `Buildout`_ recipe to generate a `Dockerfile`_ for `Birdhouse`_ applications.

.. _`Buildout`: http://buildout.org/
.. _`Dockerfile`: https://www.docker.com/
.. _`Birdhouse`: http://bird-house.github.io/

Usage
*****

The recipe will generate a Dockerfile for your application. You can find the Dockerfile in the root folder of the application. 

Supported options
=================

This recipe supports the following options:

``image-name``
   The docker image name. Default is ``ubuntu``.

``image-version``
   The docker image version. Default is ``latest``.

``maintainer``
   The name of the maintainer.

Example usage
=============

The following example ``buildout.cfg`` generates a Dockerfile for Ubuntu 14.04::

  [buildout]
  parts = docker

  [docker]
  recipe = birdhousebuilder.recipe.docker
  image-name = ubuntu
  image-version = 14.04
  maintainer = Generated by MyApp




